/* -----------------------------------------------------------------------------
 *
 * (c) The GHC Team 2010
 *
 * En/disable RTS options
 *
 * ---------------------------------------------------------------------------*/

#include "Rts.h"
#include "RtsOpts.h"

const rtsOptsEnabledEnum rtsOptsEnabled = rtsOptsSafeOnly;

